diff src/vim9execute.c @ 24002:5dbed4837ea3 v8.2.2543

patch 8.2.2543: Vim9: a return inside try/catch does not restore properly Commit: https://github.com/vim/vim/commit/9cb577a68277d46cc1134ef1723e90ff5f1d1b5c Author: Bram Moolenaar <Bram@vim.org> Date: Mon Feb 22 22:45:10 2021 +0100 patch 8.2.2543: Vim9: a return inside try/catch does not restore properly Problem: Vim9: a return inside try/catch does not restore exception state properly. Solution: When there is no ":finally" jump to ":endtry". (closes #7882)
author Bram Moolenaar <Bram@vim.org>
date Mon, 22 Feb 2021 23:00:04 +0100
parents 3daeb2060f25
children e45b2e28e45e
line wrap: on
line diff
--- a/src/vim9execute.c
+++ b/src/vim9execute.c
@@ -2517,11 +2517,13 @@ call_def_function(
 			trycmd = ((trycmd_T *)trystack->ga_data)
 							+ trystack->ga_len - 1;
 		    if (trycmd != NULL
-				  && trycmd->tcd_frame_idx == ectx.ec_frame_idx
-				  && trycmd->tcd_finally_idx != 0)
+				 && trycmd->tcd_frame_idx == ectx.ec_frame_idx)
 		    {
-			// jump to ":finally" once
-			ectx.ec_iidx = trycmd->tcd_finally_idx;
+			// jump to ":finally" or ":endtry"
+			if (trycmd->tcd_finally_idx != 0)
+			    ectx.ec_iidx = trycmd->tcd_finally_idx;
+			else
+			    ectx.ec_iidx = trycmd->tcd_endtry_idx;
 			trycmd->tcd_return = TRUE;
 		    }
 		    else